==> apache-ignite-2.6.0-src.zip: apache-ignite-2.6.0-src/modules/web-console/frontend/app/components/grid-no-data/controller.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import filter from 'lodash/fp/filter';

const rowsFiltered = filter(({ visible }) => visible);

export default class {
    static $inject = ['$scope', 'uiGridConstants'];

    constructor($scope, uiGridConstants) {
        Object.assign(this, {$scope, uiGridConstants});

        this.noData = true;
    }

    $onChanges(changes) {
        if (changes && 'gridApi' in changes && changes.gridApi.currentValue) {
            this.applyValues();

            this.gridApi.core.on.rowsVisibleChanged(this.$scope, () => {
                this.applyValues();
            });
        }
    }

    applyValues() {
        if (!this.gridApi.grid.rows.length) {
            this.noData = true;

            return;
        }

        this.noData = false;

        const filtered = rowsFiltered(this.gridApi.grid.rows);
        this.noDataFiltered = !filtered.length;
    }
}

==> apache-ignite-2.8.1-src.zip: apache-ignite-2.8.1-src/modules/web-console/frontend/app/components/grid-no-data/controller.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import _ from 'lodash';

export default class {
    static $inject = ['$scope', 'uiGridConstants'];

    constructor($scope, uiGridConstants) {
        Object.assign(this, {$scope, uiGridConstants});

        this.noData = true;
    }

    $onChanges(changes) {
        if (changes && 'gridApi' in changes && changes.gridApi.currentValue) {
            this.applyValues();

            this.gridApi.core.on.rowsVisibleChanged(this.$scope, () => {
                this.applyValues();
            });
        }
    }

    applyValues() {
        if (!this.gridApi.grid.rows.length) {
            this.noData = true;

            return;
        }

        this.noData = false;

        this.noDataFiltered = _.sumBy(this.gridApi.grid.rows, 'visible') === 0;
    }
}
